#[unsafe(no_mangle)]pub unsafe extern "C" fn posix_spawnp(
pid: *mut pid_t,
file: *const c_char,
file_actions: *const posix_spawn_file_actions_t,
attrp: *const posix_spawnattr_t,
argv: *const *mut c_char,
envp: *const *mut c_char,
) -> c_intExpand description
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/posix_spawnp.html.
Creates a new process (child process) from the specified process image. The
file argument is used to construct a pathname that identifies the new
process image file.
Returns the process ID of the child process to the parent process, in the
variable pointed to by a non-null pid argument, and shall return 0 as
the function return value. Upon error, an error number shall be returned
as the function return value.
Panics
argv must not be NULL and must contain atleast the program name.
file must also not be NULL. Failure to ensure any of this will
result in a panic.
Safety
file_actions and attrp must either be NULL or be pointers to properly
initialised objects. Doing otherwise is undefined behaviour.
file and the elements in argv must be a pointers to valid
null-terminated character arrays. Failure to ensure any of this will result
in undefined behaviour.